@@ -3,7 +3,8 @@ function(p)
 {
     tot = prod(p)
     cp = cumprod(p)
-    retval <- matrix(0, nrow = tot, ncol = length(p))
+    retval = rep.int(0, tot*length(p))
+    dim(retval) = c(tot, length(p))
     for (i in seq_along(p)) {
         retval[, i] <- rep(seq_len(p[i])-1, each=cp[i]/p[i])
     }
