@@ -3,7 +3,7 @@ function(x, y, nomatch = NA_integer_) {
 
   if (!is.list(x) && !is.list(y)) stop("Arguments must be lists")
 
-  out = rep(nomatch, length(x))
+  out = rep.int(nomatch, length(x))
 
   for (i in seq_along(x)) {
     for (j in seq_along(y)) {
